@@ -30,7 +30,7 @@ MyWidget::MyWidget() :
   Gtk::Widget(),
   m_scale(1000)
 {
-  set_flags(Gtk::NO_WINDOW);
+  set_has_window(true);
 
   //This shows the GType name, which must be used in the RC file.
   std::cout << "GType name: " << G_OBJECT_TYPE_NAME(gobj()) << std::endl;
@@ -57,7 +57,6 @@ MyWidget::~MyWidget()
 {
 }
 
-#ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
 void MyWidget::on_size_request(Gtk::Requisition* requisition)
 {
   //Initialize the output parameter:
@@ -100,9 +99,10 @@ void MyWidget::on_unmap()
 
 void MyWidget::on_realize()
 {
-  //Call base class:
-  Gtk::Widget::on_realize();
+  //Do not call base class Gtk::Widget::on_realize().
+  //It's intended only for widgets that set_has_window(false).
 
+  set_realized();
   ensure_style();
 
   //Get the themed style from the RC file:
@@ -129,12 +129,13 @@ void MyWidget::on_realize()
     attributes.window_type = GDK_WINDOW_CHILD;
     attributes.wclass = GDK_INPUT_OUTPUT;
 
-
-    m_refGdkWindow = Gdk::Window::create(get_window() /* parent */, &attributes,
+    m_refGdkWindow = Gdk::Window::create(get_parent_window(), &attributes,
             GDK_WA_X | GDK_WA_Y);
-    unset_flags(Gtk::NO_WINDOW);
     set_window(m_refGdkWindow);
 
+    //Attach this widget's style to its Gdk::Window.
+    style_attach();
+
     //set colors
     modify_bg(Gtk::STATE_NORMAL , Gdk::Color("red"));
     modify_fg(Gtk::STATE_NORMAL , Gdk::Color("blue"));
@@ -146,7 +147,7 @@ void MyWidget::on_realize()
 
 void MyWidget::on_unrealize()
 {
-  m_refGdkWindow.clear();
+  m_refGdkWindow.reset();
 
   //Call base class:
   Gtk::Widget::on_unrealize();
@@ -197,4 +198,3 @@ bool MyWidget::on_expose_event(GdkEventExpose* event)
   }
   return true;
 }
-#endif /* GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED */
